Index: base/trace_event/trace_event_memory.h |
diff --git a/base/trace_event/trace_event_memory.h b/base/trace_event/trace_event_memory.h |
index e2b3ae93060ade693c67a6717113f2ab9e42ebe9..8e70020a0896debe59ed2ada0e8c23acc5ef710a 100644 |
--- a/base/trace_event/trace_event_memory.h |
+++ b/base/trace_event/trace_event_memory.h |
@@ -20,7 +20,7 @@ |
namespace base { |
-class SingleThreadTaskRunner; |
+class MessageLoopProxy; |
namespace trace_event { |
@@ -35,14 +35,15 @@ |
typedef void (*HeapProfilerStopFunction)(); |
typedef char* (*GetHeapProfileFunction)(); |
// |task_runner| must be a task runner for the primary thread for the client |
// process, e.g. the UI thread in a browser. The function pointers must be |
// pointers to tcmalloc heap profiling functions; by avoiding direct calls to |
// these functions we avoid a dependency on third_party/tcmalloc from base. |
- TraceMemoryController(scoped_refptr<SingleThreadTaskRunner> task_runner, |
- HeapProfilerStartFunction heap_profiler_start_function, |
- HeapProfilerStopFunction heap_profiler_stop_function, |
- GetHeapProfileFunction get_heap_profile_function); |
+ TraceMemoryController( |
+ scoped_refptr<MessageLoopProxy> message_loop_proxy, |
+ HeapProfilerStartFunction heap_profiler_start_function, |
+ HeapProfilerStopFunction heap_profiler_stop_function, |
+ GetHeapProfileFunction get_heap_profile_function); |
virtual ~TraceMemoryController(); |
// base::trace_event::TraceLog::EnabledStateChangedObserver overrides: |
@@ -64,7 +65,7 @@ |
bool IsTimerRunningForTest() const; |
// Ensures the observer starts and stops tracing on the primary thread. |
- scoped_refptr<SingleThreadTaskRunner> task_runner_; |
+ scoped_refptr<MessageLoopProxy> message_loop_proxy_; |
// Pointers to tcmalloc heap profiling functions. Allows this class to use |
// tcmalloc functions without introducing a dependency from base to tcmalloc. |
@@ -35,14 +35,15 @@ |
typedef void (*HeapProfilerStopFunction)(); |
typedef char* (*GetHeapProfileFunction)(); |
- // |task_runner| must be a task runner for the primary thread for the client |
+ // |message_loop_proxy| must be a proxy to the primary thread for the client |
// process, e.g. the UI thread in a browser. The function pointers must be |
// pointers to tcmalloc heap profiling functions; by avoiding direct calls to |